package entities;

import game.Panel;
import graphics.Chord;
import graphics.Level;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;

public class Player {

  private final float MOVE_SPEED = 2.5f;
  private final float FALL_SPEED = 0.1f;
  private final float JUMP_SPEED = -10f;

  public final int PLAYER_WIDTH = 50;
  public final int PLAYER_HEIGHT = 100;

  private float x;
  private float y;
  private Color color;

  private float vx;
  private float vy;

  public boolean left;
  public boolean right;
  public boolean jump;

  private Panel panel;
  private Level level;

  public Player(Panel panel, Level level) {
    x = 0;
    y = 0;
    vx = 0;
    vy = 0;

    color = Color.GREEN;

    this.panel = panel;
    this.level = level;
  }

  private boolean isOnObstacle() {
    boolean onObstacle = false;

    for (Obstacle obstacle : level.obstacles[level.currentLevel]) {
      if (obstacle.on(this)) {
        onObstacle = true;
      }
    }

    return onObstacle;
  }

  private boolean isAir() {
    return !isScreenBottom() && !isOnObstacle();
  }

  private boolean isScreenLeft() {
    return x <= 0;
  }

  private boolean isScreenRight() {
    return x + PLAYER_WIDTH >= panel.getBounds().getWidth();
  }

  private boolean isScreenBottom() {
    return y + PLAYER_HEIGHT >= panel.getBounds().getHeight();
  }

  private boolean isScreenTop() {
    return y <= 0;
  }

  private boolean isScreenSide() {
    return (
      isScreenLeft() || isScreenRight() || isScreenBottom() || isScreenTop()
    );
  }

  public float getX() {
    return x;
  }

  public float getY() {
    return y;
  }

  public double getDistance(int x, int y) {
    float centerX = this.x + PLAYER_WIDTH / 2;
    float centerY = this.y + PLAYER_HEIGHT / 2;

    return Math.sqrt(Math.pow(centerX - x, 2) + Math.pow(centerY - y, 2));
  }

  public void update() {
    for (Chord chord : level.chords[level.currentLevel]) {
      if (getDistance(chord.x, chord.y) < 15 && !chord.collected) {
        if (chord.chordType == level.chordType) {
          level.points++;
        } else {
          level.errors++;
        }

        chord.collected = true;
        level.selectRandomChordType();
      }
    }

    if (!isAir() && vy >= 0) {
      vy = 0;
    } else {
      vy += FALL_SPEED;
    }

    if (jump && !isAir()) {
      vy += JUMP_SPEED;
      this.jump = false;
    }

    if ((!right && !left) || isScreenLeft() || isScreenRight()) {
      vx = 0;
    }

    if (right && !left && !isScreenRight()) {
      vx = MOVE_SPEED;
    }

    if (left && !right && !isScreenLeft()) {
      vx = -MOVE_SPEED;
    }

    color = isScreenSide() ? Color.RED : Color.GREEN;

    x += vx;
    y += vy;
  }

  public void draw(Graphics graphics) {
    BufferedImage img;

    try {
      img = ImageIO.read(new File("assets/img/key.png"));
    } catch (IOException e) {
      throw new RuntimeException(e);
    }

    graphics.setColor(color);
    //graphics.fillRect((int) x, (int) y, PLAYER_WIDTH, PLAYER_HEIGHT);

    graphics.drawImage(
      img,
      (int) x,
      (int) y,
      PLAYER_WIDTH,
      PLAYER_HEIGHT,
      null
    );

    graphics.setColor(Color.RED);
    //graphics.fillRect((int) x + PLAYER_WIDTH / 2, (int) y + PLAYER_HEIGHT / 2, 2, 2);
  }
}
