package graphics;

import java.awt.*;
import java.util.concurrent.ThreadLocalRandom;

enum ChordType {
  MAJOR,
  MINOR,
  SUS2,
  SUS4,
}

public class Chord {

  public int x;
  public int y;
  public boolean collected = false;
  public ChordType chordType;

  public String text;

  public static String[] notes = new String[12];

  public Chord(int x, int y) {
    this.x = x;
    this.y = y;

    notes = new String[] {
      "C",
      "C#/Db",
      "D",
      "D#/Eb",
      "E",
      "F",
      "F#/Gb",
      "G",
      "G#/Ab",
      "A",
      "A#/Hb",
      "H",
    };

    int type = ThreadLocalRandom.current().nextInt(1, 5);
    int root = ThreadLocalRandom.current().nextInt(0, 12);

    switch (type) {
      case 1 -> {
        chordType = ChordType.MAJOR;
        text =
          notes[root] +
          " " +
          notes[(root + 4) % 12] +
          " " +
          notes[(root + 7) % 12];
      }
      case 2 -> {
        chordType = ChordType.MINOR;
        text =
          notes[root] +
          " " +
          notes[(root + 3) % 12] +
          " " +
          notes[(root + 7) % 12];
      }
      case 3 -> {
        chordType = ChordType.SUS2;
        text =
          notes[root] +
          " " +
          notes[(root + 2) % 12] +
          " " +
          notes[(root + 7) % 12];
      }
      case 4 -> {
        chordType = ChordType.SUS4;
        text =
          notes[root] +
          " " +
          notes[(root + 5) % 12] +
          " " +
          notes[(root + 7) % 12];
      }
    }
  }

  public void draw(Graphics graphics) {
    graphics.setColor(collected ? Color.GREEN : Color.DARK_GRAY);
    graphics.setFont(new Font(Font.MONOSPACED, Font.BOLD, 20));

    int textWidth = graphics.getFontMetrics().stringWidth(text);
    int boxWidth = textWidth + 50;
    int boxHeight = 50;

    graphics.drawRect(x - boxWidth / 2, y - boxHeight / 2, boxWidth, boxHeight);
    graphics.drawString(text, x - textWidth / 2, y + 7);
    //graphics.setColor(Color.RED);
    //graphics.drawRect(x, y, 1, 1);
  }
}
