package graphics;

import entities.Obstacle;
import entities.Player;
import java.awt.*;
import java.util.concurrent.ThreadLocalRandom;

public class Level {

  public final Player player;
  private final game.Panel panel;

  private final LevelIndicator levelIndicator;
  private final PointsIndicator pointsIndicator;
  private final ChordTypeIndicator chordTypeIndicator;
  private final LevelCompleteIndicator levelCompleteIndicator;

  private final int MIN_LEVEL = 0;
  private final int MAX_LEVEL = 2;

  public int currentLevel = 0;
  public ChordType chordType = ChordType.MAJOR;

  public String[] names;
  public Obstacle[][] obstacles = new Obstacle[3][10];
  public Chord[][] chords = new Chord[3][8];
  public boolean[] completed = new boolean[3];

  public int points = 0;
  public int errors = 0;

  public Level(game.Panel panel) {
    this.panel = panel;
    this.player = new Player(panel, this);

    this.levelIndicator = new LevelIndicator(
      panel.getWidth() - LevelIndicator.WIDTH - 25,
      25,
      this
    );
    this.pointsIndicator = new PointsIndicator(
      panel.getWidth() - PointsIndicator.WIDTH - 25,
      25 + LevelIndicator.HEIGHT + 25,
      this
    );
    this.chordTypeIndicator = new ChordTypeIndicator(
      panel.getWidth() - ChordTypeIndicator.WIDTH - 25,
      25 + LevelIndicator.HEIGHT + 25 + PointsIndicator.HEIGHT + 25,
      this
    );
    this.levelCompleteIndicator = new LevelCompleteIndicator(
      panel.getWidth() - LevelCompleteIndicator.WIDTH - 25,
      25 +
      LevelIndicator.HEIGHT +
      25 +
      PointsIndicator.HEIGHT +
      25 +
      ChordTypeIndicator.HEIGHT +
      25,
      this
    );

    completed = new boolean[] { false, false, false };

    obstacles[0] = new Obstacle[] {
      new Obstacle(0, 800, 100, 20),
      new Obstacle(400, 600, 100, 20),
    };

    chords[0] = new Chord[] {
      new Chord(200, 800),
      new Chord(150, 300),
      new Chord(850, 150),
    };

    obstacles[1] = new Obstacle[] {
      new Obstacle(500, 600, 150, 20),
      new Obstacle(500, 800, 70, 20),
    };

    chords[1] = new Chord[] {
      new Chord(500, 900),
      new Chord(250, 300),
      new Chord(430, 200),
    };

    obstacles[2] = new Obstacle[] {
      new Obstacle(0, 600, 90, 80),
      new Obstacle(250, 800, 70, 60),
      new Obstacle(500, 100, 70, 10),
    };

    chords[2] = new Chord[] {
      new Chord(100, 100),
      new Chord(140, 300),
      new Chord(250, 200),
      new Chord(550, 700),
      new Chord(250, 700),
    };

    selectRandomChordType();
  }

  public void draw(Graphics graphics) {
    player.draw(graphics);
    levelIndicator.draw(graphics);
    pointsIndicator.draw(graphics);
    chordTypeIndicator.draw(graphics);
    levelCompleteIndicator.draw(graphics);

    for (Obstacle obstacle : obstacles[currentLevel]) {
      obstacle.draw(graphics);
    }

    for (Chord chord : chords[currentLevel]) {
      chord.draw(graphics);
    }
  }

  public void selectRandomChordType() {
    if (completed[currentLevel]) {
      return;
    }

    if (allChordsCollected()) {
      completed[currentLevel] = true;
      return;
    }

    ChordType randomType = ChordType.MAJOR;

    while (!typePresent(randomType)) {
      System.out.println(randomType + " not present, trying again");

      int type = ThreadLocalRandom.current().nextInt(1, 5);

      switch (type) {
        case 1 -> randomType = ChordType.MAJOR;
        case 2 -> randomType = ChordType.MINOR;
        case 3 -> randomType = ChordType.SUS2;
        case 4 -> randomType = ChordType.SUS4;
      }
    }

    chordType = randomType;
  }

  private boolean allChordsCollected() {
    for (Chord chord : chords[currentLevel]) {
      if (!chord.collected) {
        return false;
      }
    }

    return true;
  }

  private boolean typePresent(ChordType type) {
    for (Chord chord : chords[currentLevel]) {
      if (chord.chordType == type && !chord.collected) {
        return true;
      }
    }

    return false;
  }

  public void nextLevel() {
    if (currentLevel < MAX_LEVEL) {
      currentLevel++;
    }
  }

  public void prevLevel() {
    if (currentLevel > MIN_LEVEL) {
      currentLevel--;
    }
  }

  public void update() {
    player.update();
  }
}
