package graphics;

import game.Game;
import game.Panel;
import game.State;
import java.awt.*;
import java.awt.event.MouseEvent;

public class Menu {

  private final MenuButton[] menuButtons = new MenuButton[3];
  private final int BUTTON_SPACING = 50;

  private final game.Panel panel;
  private final Level level;
  private final SoundButton soundButton;
  private final NextPrevButton nextPrevButton;
  private final LevelIndicator levelIndicator;
  private final Game game;

  public Menu(Panel panel, Level level, Game game) {
    this.panel = panel;
    this.level = level;
    this.soundButton = new SoundButton(25, 25);
    this.nextPrevButton = new NextPrevButton(
      25,
      25 + SoundButton.BUTTON_HEIGHT + 25
    );
    this.levelIndicator = new LevelIndicator(
      panel.getWidth() - LevelIndicator.WIDTH - 25,
      25,
      level
    );
    this.game = game;

    int x = (panel.getWidth() - MenuButton.BUTTON_WIDTH) / 2;

    int stackHeight =
      menuButtons.length * MenuButton.BUTTON_HEIGHT +
      (menuButtons.length - 1) * BUTTON_SPACING;
    int y = (panel.getHeight() - stackHeight) / 2;

    menuButtons[0] = new MenuButton(x, y, "Continue", State.PLAY);
    menuButtons[1] = new MenuButton(
      x,
      y + MenuButton.BUTTON_HEIGHT + BUTTON_SPACING,
      "Credits",
      State.CREDITS
    );
    menuButtons[2] = new MenuButton(
      x,
      y + 2 * MenuButton.BUTTON_HEIGHT + 2 * BUTTON_SPACING,
      "Quit",
      State.QUIT
    );
  }

  public void draw(Graphics graphics) {
    drawTitle(graphics);
    soundButton.draw(graphics);
    nextPrevButton.draw(graphics);
    levelIndicator.draw(graphics);

    for (MenuButton menuButton : menuButtons) {
      menuButton.draw(graphics);
    }
  }

  private void drawTitle(Graphics graphics) {
    graphics.setColor(Color.DARK_GRAY);
    graphics.setFont(new Font(Font.MONOSPACED, Font.BOLD, 60));

    int textWidth = graphics.getFontMetrics().stringWidth(Game.GAME_NAME);
    int boxWidth = textWidth + 100;

    int x = (panel.getWidth() - boxWidth) / 2;
    int y = 100;

    graphics.drawRect(x, y, boxWidth, 100);

    int xOffset = (boxWidth - textWidth) / 2;
    int yOffset = 65;

    graphics.drawString(Game.GAME_NAME, x + xOffset, y + yOffset);
  }

  public void update() {}

  public void mouseClicked(MouseEvent e) {
    for (MenuButton menuButton : menuButtons) {
      if (menuButton.in(e)) {
        State.state = menuButton.effect;
      }
    }

    if (nextPrevButton.inNext(e)) {
      level.nextLevel();
    }

    if (nextPrevButton.inPrev(e)) {
      level.prevLevel();
    }

    if (soundButton.in(e)) {
      game.music = !game.music;
    }
  }
}
