package graphics;

import game.State;
import java.awt.*;
import java.awt.event.MouseEvent;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import javax.imageio.ImageIO;

public class NextPrevButton {

  private final int x;
  private final int y;

  public static final int BUTTON_WIDTH = 100;
  public static final int BUTTON_HEIGHT = 100;

  private final int IMG_WIDTH = 50;
  private final int IMG_HEIGHT = 70;
  private final int SPACING = 25;

  public NextPrevButton(int x, int y) {
    this.x = x;
    this.y = y;
  }

  public void draw(Graphics graphics) {
    BufferedImage nextImg;
    BufferedImage prevImg;

    try {
      nextImg = ImageIO.read(new File("assets/img/next.png"));
      prevImg = ImageIO.read(new File("assets/img/prev.png"));
    } catch (IOException e) {
      throw new RuntimeException(e);
    }

    graphics.setColor(Color.DARK_GRAY);
    graphics.drawRect(x, y, BUTTON_WIDTH, BUTTON_HEIGHT);
    graphics.drawRect(
      x + BUTTON_WIDTH + SPACING,
      y,
      BUTTON_WIDTH,
      BUTTON_HEIGHT
    );

    int xOffset1 = (BUTTON_WIDTH - IMG_WIDTH) / 2;
    int xOffset2 = xOffset1 + BUTTON_WIDTH + SPACING;
    int yOffset = (BUTTON_HEIGHT - IMG_HEIGHT) / 2;

    graphics.drawImage(
      prevImg,
      x + xOffset1,
      y + yOffset,
      IMG_WIDTH,
      IMG_HEIGHT,
      null
    );
    graphics.drawImage(
      nextImg,
      x + xOffset2,
      y + yOffset,
      IMG_WIDTH,
      IMG_HEIGHT,
      null
    );
  }

  public boolean inPrev(MouseEvent e) {
    boolean xIn = e.getX() > x && e.getX() < x + BUTTON_WIDTH;
    boolean yIn = e.getY() > y && e.getY() < y + BUTTON_HEIGHT;

    return xIn && yIn;
  }

  public boolean inNext(MouseEvent e) {
    boolean xIn =
      e.getX() > x + BUTTON_WIDTH + SPACING &&
      e.getX() < x + BUTTON_WIDTH + SPACING + BUTTON_WIDTH;
    boolean yIn = e.getY() > y && e.getY() < y + BUTTON_HEIGHT;

    return xIn && yIn;
  }
}
